@@ -167,7 +167,7 @@ var localProxyStartCmd = &console.Command{
 		shutdownCh := make(chan bool, 1)
 		go func() {
 			sigsCh := make(chan os.Signal, 1)
-			signal.Notify(sigsCh, syscall.SIGINT, syscall.SIGQUIT, syscall.SIGTERM)
+			signal.Notify(sigsCh, os.Interrupt, syscall.SIGQUIT, syscall.SIGTERM)
 			<-sigsCh
 			signal.Stop(sigsCh)
 			shutdownCh <- true
