@@ -52,6 +52,7 @@ import (
 
 var localWebServerProdWarningMsg = "The local web server is optimized for local development and MUST never be used in a production setup."
 var localWebServerTlsKeyLogWarningMsg = "Logging TLS master key is enabled. It means TLS connections between the client and this server will be INSECURE. This is NOT recommended unless you are debugging the connections."
+var localWebServerAllowsCORSLogWarningMsg = "Cross-origin resource sharing (CORS) is enabled for all requests.\nYou may want to use https://github.com/nelmio/NelmioCorsBundle to have better control over HTTP headers."
 
 var localServerStartCmd = &console.Command{
 	Category:    "local",
@@ -83,6 +84,7 @@ var localServerStartCmd = &console.Command{
 			EnvVars: []string{"SSLKEYLOGFILE"},
 		},
 		&console.BoolFlag{Name: "no-workers", Usage: "Do not start workers"},
+		&console.BoolFlag{Name: "allow-cors", Usage: "Allow Cross-origin resource sharing (CORS) requests"},
 	},
 	Action: func(c *console.Context) error {
 		ui := terminal.SymfonyStyle(terminal.Stdout, terminal.Stdin)
@@ -188,6 +190,10 @@ var localServerStartCmd = &console.Command{
 			ui.Warning(localWebServerTlsKeyLogWarningMsg)
 		}
 
+		if config.AllowCORS {
+			ui.Warning(localWebServerAllowsCORSLogWarningMsg)
+		}
+
 		lw, err := pidFile.LogWriter()
 		if err != nil {
 			return err
